@@ -31,10 +31,12 @@ namespace LongoMatch.Gui.Dialog
 			this.Build();
 		}
 		
-		public ProjectType Type{
+		public ProjectType ProjectType{
 			get{
 				if (fromfileradiobutton.Active)
 					return ProjectType.FileProject;
+				else if (liveradiobutton.Active)
+					return ProjectType.CaptureProject;				
 				else
 					return ProjectType.FakeCaptureProject;
 				
